@@ -6,7 +6,7 @@ use Dist::Joseki;
 use Dist::Joseki::Find;
 
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 
 use base 'Dist::Joseki::Cmd::Multiplexable';
@@ -73,7 +73,8 @@ L<Dist::Joseki::Cmd::Multiplexable>.
 The superclass L<Dist::Joseki::Cmd::Multiplexable> defines these methods
 and functions:
 
-    hook_before_dist_loop(), hook_in_dist_loop_end(), options(), run()
+    handle_dist_error(), hook_before_dist_loop(), hook_in_dist_loop_end(),
+    options(), run(), try_single()
 
 The superclass L<Dist::Joseki::Cmd::Command> defines these methods and
 functions:
@@ -131,7 +132,7 @@ please use the C<distjoseki> tag.
 
 =head1 VERSION 
                    
-This document describes version 0.13 of L<Dist::Joseki::Cmd::Command::clean>.
+This document describes version 0.14 of L<Dist::Joseki::Cmd::Command::clean>.
 
 =head1 BUGS AND LIMITATIONS
 
@@ -151,13 +152,13 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
 site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Marcel GrE<uuml>nauer
+Copyright 2007-2008 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
