@@ -11,7 +11,7 @@ use Parse::CPAN::Packages;
 use Perl::Version;
 
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 
 use base 'Dist::Joseki::Cmd::Multiplexable';
@@ -182,8 +182,8 @@ L<Dist::Joseki::Cmd::Multiplexable>.
 The superclass L<Dist::Joseki::Cmd::Multiplexable> defines these methods
 and functions:
 
-    hook_after_dist_loop(), hook_before_dist_loop(),
-    hook_in_dist_loop_begin(), hook_in_dist_loop_end(), run()
+    handle_dist_error(), hook_after_dist_loop(), hook_before_dist_loop(),
+    hook_in_dist_loop_begin(), hook_in_dist_loop_end(), run(), try_single()
 
 The superclass L<Dist::Joseki::Cmd::Command> defines these methods and
 functions:
@@ -241,7 +241,7 @@ please use the C<distjoseki> tag.
 
 =head1 VERSION 
                    
-This document describes version 0.13 of L<Dist::Joseki::Cmd::Command::depends>.
+This document describes version 0.14 of L<Dist::Joseki::Cmd::Command::depends>.
 
 =head1 BUGS AND LIMITATIONS
 
@@ -261,13 +261,13 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
 site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Marcel GrE<uuml>nauer
+Copyright 2007-2008 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
