@@ -3,9 +3,10 @@ package Dist::Joseki::Cmd::Multiplexable;
 use strict;
 use warnings;
 use Dist::Joseki::Find;
+use Error ':try';
 
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 
 use base qw(Dist::Joseki::Cmd::Command);
@@ -15,7 +16,7 @@ sub options {
     my ($self, $app, $cmd_config) = @_;
     return (
         $self->SUPER::options($app, $cmd_config),
-        [ 'proj|p' => 'Repeat this for all distributions in the project' ],
+        [ 'proj|p'   => 'Repeat this for all distributions in the project' ],
     );
 }
 
@@ -28,19 +29,35 @@ sub run {
 
         $self->hook_before_dist_loop;
         for my $dist (Dist::Joseki::Find->new->find_dists) {
-            chdir $dist or die "can't chdir to $dist: $!\n";
-            $self->hook_in_dist_loop_begin($dist);
-            $self->run_single;
-            $self->hook_in_dist_loop_end($dist);
+                chdir $dist or die "can't chdir to $dist: $!\n";
+                $self->hook_in_dist_loop_begin($dist);
+                $self->try_single($dist);
+                $self->hook_in_dist_loop_end($dist);
         }
         $self->hook_after_dist_loop;
-
     } else {
-        $self->run_single;
+        $self->try_single;
     }
 }
 
 
+sub try_single {
+    my ($self, $dist) = @_;
+    $dist = 'current' unless defined $dist;
+    try {
+        $self->run_single;
+    } catch Error with {
+        $self->handle_dist_error($dist, $_[0]);
+    };
+}
+
+
+sub handle_dist_error {
+    my ($self, $dist, $error) = @_;
+    warn "distribution [$dist] had an error:\n$error\n";
+}
+
+
 sub hook_before_dist_loop   {}
 sub hook_after_dist_loop    {}
 sub hook_in_dist_loop_begin {}
@@ -134,7 +151,7 @@ please use the C<distjoseki> tag.
 
 =head1 VERSION 
                    
-This document describes version 0.13 of L<Dist::Joseki::Cmd::Multiplexable>.
+This document describes version 0.14 of L<Dist::Joseki::Cmd::Multiplexable>.
 
 =head1 BUGS AND LIMITATIONS
 
@@ -154,13 +171,13 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
 site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Marcel GrE<uuml>nauer
+Copyright 2007-2008 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
