@@ -6,7 +6,7 @@ use strict;
 use base 'Dist::Joseki::DistType::Base';
 
 
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 
 sub is_built {
@@ -18,7 +18,7 @@ sub is_built {
 sub ACTION_build {
     my $self = shift;
     return if $self->is_built;
-    $self->safe_system('perl', 'Makefile.PL');
+    $self->safe_system($^X, 'Makefile.PL');
 }
 
 
@@ -129,7 +129,7 @@ please use the C<distjoseki> tag.
 
 =head1 VERSION 
                    
-This document describes version 0.13 of L<Dist::Joseki::DistType::MakeMaker>.
+This document describes version 0.14 of L<Dist::Joseki::DistType::MakeMaker>.
 
 =head1 BUGS AND LIMITATIONS
 
@@ -149,13 +149,13 @@ The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
 site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
 
-=head1 AUTHOR
+=head1 AUTHORS
 
 Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Marcel GrE<uuml>nauer
+Copyright 2007-2008 by the authors.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
